This is the preprocessor code that used to be part of Fast Downward
(http://www.fast-downward.org/) augmented with the h^2-mutex-pruning code
by Vidal Alcázar and Álvaro Torralba. Details about the latter can be
found in their paper "A Reminder about the Importance of Computing and
Exploiting Invariants in Planning", ICAPS 2015.

See `CMakeLists.txt` for compilation instructions.

The resulting binary is called `preprocess`. It expects an `output.sas`
file (as generated by Fast Downward's "translate" component) as input on
stdin and writes its output to `output.sas` (existing files with this name
will be overwritten). The program can therefore be used as an intermediate
step between Fast Downward's "translate" and "search" steps.
